1.0.0 API documentation: quaternion_exponential.hpp File Reference

| 1.0.0 API documentation

Functions
quaternion_exponential.hpp File Reference

GLM_EXT_quaternion_exponential More...

Go to the source code of this file.

## Functions
template<typename T , qualifier Q>
GLM_FUNC_DECL qua< T, Q > | exp (qua< T, Q > const &q)
| Returns a exponential of a quaternion. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL qua< T, Q > | log (qua< T, Q > const &q)
| Returns a logarithm of a quaternion. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL qua< T, Q > | pow (qua< T, Q > const &q, T y)
| Returns a quaternion raised to a power. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL qua< T, Q > | sqrt (qua< T, Q > const &q)
| Returns the square root of a quaternion. More...

## Detailed Description

GLM_EXT_quaternion_exponential

Definition in file quaternion_exponential.hpp.